## Minimum hardware requirements for OAI CN5G and OAI gNB
    1. Operating System: Ubuntu 20.04.5 LTS
    3. CPU: 8 cores x86_64 @ 3.5 GHz
    2. RAM: 32 GB

## Minimum hardware requirements for OAI UE
    1. CPU: 4 cores x86_64
    2. RAM: 8 GB
    
## 5G Core Installation
### General Instruction
    Important: The following steps can be executed by the file oai_5g_core_install.sh
    In this task you will install and configure the core in its basic architecture according to the image below:
    
![ALT](/openairinterface5g/openairinterface-conf/fig/oai_core.png)  

    Step 1: Install dependencies 
        sudo apt-get install ca-certificates 
        sudo apt-get install curl 
        sudo apt-get install gnupg 
        sudo apt-get install lsb-release 

    Step 2: Enable packet forwarding
        sudo sysctl net.ipv4.conf.all.forwarding=1
        sudo iptables -P FORWARD ACCEPT

    Step 3: Install docker and docker-compose
        sudo rm /etc/apt/sources.list.d/docker.list*
        sudo mkdir -p /etc/apt/keyrings 
        curl -fsSL https://download.docker.com/linux/ubuntu/gpg | sudo apt-key add -
        sudo add-apt-repository "deb [arch=amd64] https://download.docker.com/linux/ubuntu $(. /etc/os-release; echo "$UBUNTU_CODENAME") stable"
        sudo chmod a+r /etc/apt/keyrings/docker.gpg
        sudo apt-get update
        sudo apt-get install docker-ce docker-ce-cli containerd.io docker-compose-plugin
        sudo curl -L https://github.com/docker/compose/releases/download/1.29.2/docker-compose-`uname -s`-`uname -m` -o /usr/local/bin/docker-compose
        sudo chmod +x /usr/local/bin/docker-compose
    
    Step 4: Pull the images from Docker Hub
        sudo docker pull oaisoftwarealliance/oai-amf:v1.5.0
        sudo docker pull oaisoftwarealliance/oai-nrf:v1.5.0
        sudo docker pull oaisoftwarealliance/oai-smf:v1.5.0
        sudo docker pull oaisoftwarealliance/oai-udr:v1.5.0
        sudo docker pull oaisoftwarealliance/oai-udm:v1.5.0
        sudo docker pull oaisoftwarealliance/oai-ausf:v1.5.0
        sudo docker pull oaisoftwarealliance/oai-spgwu-tiny:v1.5.0
        sudo docker pull oaisoftwarealliance/trf-gen-cn5g:latest

    Step 5: Tag Docker Images
        sudo docker image tag oaisoftwarealliance/trf-gen-cn5g:latest trf-gen-cn5g:latest
        sudo docker image tag oaisoftwarealliance/oai-amf:v1.5.0 oai-amf:v1.5.0
        sudo docker image tag oaisoftwarealliance/oai-nrf:v1.5.0 oai-nrf:v1.5.0
        sudo docker image tag oaisoftwarealliance/oai-smf:v1.5.0 oai-smf:v1.5.0
        sudo docker image tag oaisoftwarealliance/oai-udr:v1.5.0 oai-udr:v1.5.0
        sudo docker image tag oaisoftwarealliance/oai-udm:v1.5.0 oai-udm:v1.5.0
        sudo docker image tag oaisoftwarealliance/oai-ausf:v1.5.0 oai-ausf:v1.5.0
        sudo docker image tag oaisoftwarealliance/oai-spgwu-tiny:v1.5.0 oai-spgwu-tiny:v1.5.0

    Step 6: Clone OpenAirInterface 5G Core repository
        git clone https://gitlab.eurecom.fr/oai/cn5g/oai-cn5g-fed.git
        cd oai-cn5g-fed
        git checkout -f v1.5.0

## RAN and UE installation (Split and Monolithic mode)
### General Instruction
    In this task you will install and configure the gNB of the OAI.

    Step 1: Install dependencies
        sudo add-apt-repository ppa:ettusresearch/uhd
        sudo apt-get install libuhd-dev uhd-host -y
        sudo apt-get install libuhd4.2.0 -y
        sudo apt-get install libuhd4.4.0 -y

    Step 2: Fix problem in the libuhd
        sudo dpkg -i --force-overwrite /var/cache/apt/archives/libuhd4.2.0_4.2.0.1-0ubuntu1~focal1_amd64.deb
        sudo dpkg -i --force-overwrite /var/cache/apt/archives/libuhd4.4.0_4.4.0.0-0ubuntu1~focal1_amd64.deb

    Step 3: Clone OpenAirInterface 5G RAN and UE repository
        git clone https://gitlab.eurecom.fr/oai/openairinterface5g.git
        cd PATH_TO/openairinterface5g
        git checkout develop
    
    Step 4: Run the installation script
        source oaienv
        cd cmake_targets
        sudo ./build_oai -I -w USRP -i
        sudo ./build_oai --gNB --nrUE -w USRP